import { pgTable, text, serial, integer, boolean, timestamp, real } from "drizzle-orm/pg-core";
import { createInsertSchema } from "drizzle-zod";
import { z } from "zod";

export const users = pgTable("users", {
  id: serial("id").primaryKey(),
  username: text("username").notNull().unique(),
  password: text("password").notNull(),
});

export const signals = pgTable("signals", {
  id: serial("id").primaryKey(),
  pair: text("pair").notNull(),
  direction: text("direction").notNull(), // 'CALL' or 'PUT'
  confidence: integer("confidence").notNull(),
  strategies: text("strategies").array().notNull(),
  timestamp: timestamp("timestamp").defaultNow().notNull(),
  result: text("result"), // 'WIN', 'LOSS', or null (pending)
  pnl: real("pnl"), // profit/loss amount
  martingaleStep: integer("martingale_step").default(1),
});

export const marketData = pgTable("market_data", {
  id: serial("id").primaryKey(),
  pair: text("pair").notNull(),
  price: real("price").notNull(),
  change: real("change").notNull(),
  changePercent: real("change_percent").notNull(),
  timestamp: timestamp("timestamp").defaultNow().notNull(),
});

export const insertUserSchema = createInsertSchema(users).pick({
  username: true,
  password: true,
});

export const insertSignalSchema = createInsertSchema(signals).omit({
  id: true,
  timestamp: true,
});

export const insertMarketDataSchema = createInsertSchema(marketData).omit({
  id: true,
  timestamp: true,
});

export type InsertUser = z.infer<typeof insertUserSchema>;
export type User = typeof users.$inferSelect;
export type Signal = typeof signals.$inferSelect;
export type InsertSignal = z.infer<typeof insertSignalSchema>;
export type MarketData = typeof marketData.$inferSelect;
export type InsertMarketData = z.infer<typeof insertMarketDataSchema>;

// Real-time data types
export interface LiveSignal {
  pair: string;
  direction: 'CALL' | 'PUT';
  confidence: number;
  strategies: string[];
  timestamp: Date;
  martingaleStep?: number;
}

export interface TechnicalIndicator {
  name: string;
  value: number | string;
  signal: 'BULLISH' | 'BEARISH' | 'NEUTRAL';
  status: 'active' | 'warning' | 'inactive';
}

export interface CandleData {
  timestamp: Date;
  open: number;
  high: number;
  low: number;
  close: number;
  volume?: number;
}

export interface StrategyPerformance {
  name: string;
  accuracy: number;
  signals: number;
  wins: number;
  losses: number;
}
